@@ -16,6 +16,7 @@ import pytest
 
 from dask.system import CPU_COUNT
 from distributed import Client, Worker, Nanny, get_client
+from distributed.core import Status
 from distributed.deploy.local import LocalCluster, nprocesses_nthreads
 from distributed.metrics import time
 from distributed.system import MEMORY_LIMIT
@@ -188,7 +189,7 @@ def test_Client_with_local(loop):
 def test_Client_solo(loop):
     with Client(loop=loop, silence_logs=False) as c:
         pass
-    assert c.cluster.status == "closed"
+    assert c.cluster.status == Status.closed
 
 
 @gen_test()
@@ -223,7 +224,7 @@ def test_Client_kwargs(loop):
     with Client(loop=loop, processes=False, n_workers=2, silence_logs=False) as c:
         assert len(c.cluster.workers) == 2
         assert all(isinstance(w, Worker) for w in c.cluster.workers.values())
-    assert c.cluster.status == "closed"
+    assert c.cluster.status == Status.closed
 
 
 def test_Client_unused_kwargs_with_cluster(loop):
@@ -997,6 +998,18 @@ async def test_repr(cleanup):
         assert "memory" not in repr(cluster)
 
 
+@pytest.mark.asyncio
+async def test_threads_per_worker_set_to_0(cleanup):
+    with pytest.warns(
+        Warning, match="Setting `threads_per_worker` to 0 is discouraged."
+    ):
+        async with LocalCluster(
+            n_workers=2, processes=False, threads_per_worker=0, asynchronous=True,
+        ) as cluster:
+            assert len(cluster.workers) == 2
+            assert all(w.nthreads < CPU_COUNT for w in cluster.workers.values())
+
+
 @pytest.mark.asyncio
 @pytest.mark.parametrize("temporary", [True, False])
 async def test_capture_security(cleanup, temporary):
